@@ -690,7 +690,8 @@ hhws_settings_dialog (Hhws *hhws)
   g_object_set (G_OBJECT (priv->entry_url),
                 "hildon-input-mode",
                 HILDON_GTK_INPUT_MODE_ALPHA|HILDON_GTK_INPUT_MODE_NUMERIC|
-                HILDON_GTK_INPUT_MODE_SPECIAL);
+                HILDON_GTK_INPUT_MODE_SPECIAL,
+                NULL);
 
   if (priv->uri)
     gtk_entry_set_text (GTK_ENTRY (priv->entry_url),
